
# Slot: last_updated_on


time at which the element was last updated

URI: [linkml:last_updated_on](https://w3id.org/linkml/last_updated_on)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..1</sub> [Datetime](Datetime.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | pav:lastUpdatedOn |

